# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307, USA, or go to
# http://www.gnu.org/copyleft/lesser.txt.
#-----------------------------------------------------------------------------
# Name        	: openttd.rb
# Description 	: Various stuff for creating custom scenery for Ataris RollerCoaster Tycoon 3
# Menu Item   	: Plugins\OpenTTD
# Author      	: Belgabor
# Usage     	: Copy script to PLUGINS folder in SketchUp folder
# Date        	: 24/02/2009
# Type        	: Various
# Version     	: 0.1 Initial Version
#-----------------------------------------------------------------------------

require 'sketchup.rb'

module OpenTTD

def OpenTTD::make_grid(gr, x, y)
	model = Sketchup.active_model
	model.start_operation "Create construction lines for #{gr}"
	
	entities = model.active_entities
	group = entities.add_group
	group.name = gr
	entities = group.entities
	
	entities.add_cline([x-625.cm, y-625.cm, 0], [x+625.cm, y-625.cm,0], "_")
	entities.add_cline([x-625.cm, y+625.cm, 0], [x+625.cm, y+625.cm,0], "_")
	entities.add_cline([x-625.cm, y-625.cm, 0], [x-625.cm, y+625.cm,0], "_")
	entities.add_cline([x+625.cm, y-625.cm, 0], [x+625.cm, y+625.cm,0], "_")
	
	entities.add_cline([x-625.cm, y-3125.mm, 0], [x+625.cm, y-3125.mm,0], ".")
	entities.add_cline([x-625.cm, y+3125.mm, 0], [x+625.cm, y+3125.mm,0], ".")
	entities.add_cline([x-3125.mm, y-625.cm, 0], [x-3125.mm, y+625.cm,0], ".")
	entities.add_cline([x+3125.mm, y-625.cm, 0], [x+3125.mm, y+625.cm,0], ".")
		
	entities.add_cline([x-625.cm, y, 0], [x+625.cm, y,0], ".")
	entities.add_cline([x, y-625.cm, 0], [x, y+625.cm,0], ".")
		
	model.commit_operation
end

def OpenTTD::set_cam(x, y, z, lx, ly, lz)
	Sketchup.active_model.active_view.camera = Sketchup::Camera.new(Geom::Point3d.new(x,y,z), Geom::Point3d.new(lx,ly,lz), Geom::Vector3d.new(0,0,1), false)
	Sketchup.active_model.active_view.camera
end

def OpenTTD::cam
	Sketchup.active_model.active_view.camera
end

end 

if( not file_loaded?("openttd.rb") )

	main_menu = UI.menu("Plugins").add_submenu("OpenTTD")
	main_menu.add_item("Camera") { OpenTTD::set_cam(36053.mm,36053.mm,41938.mm,0,0,1250.cm) }
	
	square_menu = main_menu.add_submenu("Square grids")
	square_menu.add_item("12.5 x 12.5") { OpenTTD::make_grid("One OpenTTD square", 0, 0) }
end
file_loaded("openttd.rb")
